#!/usr/bin/env python
# The World Dissolved
# An Interactive Novel by Phil Bordelon
#

import cPickle
import sys
import tools

class State:

   def __init__ (self):
      self.location_dict = {}
      self.global_state = {"allowed-action-dict": {}}

   def handleLocation(self, curr_loc_dict):
      """Handles a location.  Elements in the curr_loc_dict:
         name = the name of the location.  REQUIRED.
         text = the name of the text file with the data
         actions = a list of 3 or 4-tuples of actions:
            keyword, display_line, function_to_call_when_chosen(, parameters)
   
         This handles Q, S, L, and ? properly.
      """
   
      self.global_state["location"] = curr_loc_dict["name"]
      command = "?"
      while command == "?":
         print
         if curr_loc_dict.get("can-brief"):
            if curr_loc_dict.get("brief"):
               tools.displayData(curr_loc_dict["text"]+"-brief")
            else:
               tools.displayData(curr_loc_dict["text"])
               curr_loc_dict["brief"] = True
         else:
            tools.displayData(curr_loc_dict["text"])
         if not curr_loc_dict.has_key("actions"):
            curr_loc_dict["actions"] = [("idle", "IDLE because the developer forgot to put actions",
                      tools.Idle)]
   
         prompt = True
         if curr_loc_dict.get("no-prompt"):
            prompt = False
         if self.global_state["allowed-action-dict"].get(curr_loc_dict["name"]):
            command = tools.chooseAction(curr_loc_dict["actions"], self.global_state["allowed-action-dict"][curr_loc_dict["name"]], prompt)
         else:
            command = tools.chooseAction(curr_loc_dict["actions"], [], prompt)
   
         if command == "q":
            sys.exit(0)
         elif command == "s":
            self.save()
         elif command == "l":
            self.load()
         elif command == "?":
            if curr_loc_dict.get("can-brief"):
               curr_loc_dict["brief"] = False
         else:
            for action in curr_loc_dict["actions"]:
               if action[0] == command:
                  if len(action) == 4:
                     action[2](action[3])
                  else:
                     action[2]()

   def move(self, location):
      """Move to a location.
      Some locations may have a function that needs to be called before they're
      entered; if so, location_dict[location] should have an entry called
      "pre-function", which will be either a 1- or 2-list of a function or
      function and parameter list to run.  This function call occurs BEFORE
      the move is done, so things can be done depending on what room you're
      entering from, etc.  There is also a post-function, which runs /after/
      the move, so it can be dependent on the room being entered."""

      if not self.location_dict.get(location):
         print "ERROR: Cannot move to nonexistent location %s!" % location
      else:
         pf_list = self.location_dict[location].get("pre-function")
         if pf_list:
            if len(pf_list) == 1:
               pf_list[0]()
            else:
               pf_list[0](pf_list[1])
         self.global_state["location"] = location
         pf_list = self.location_dict[location].get("post-function")
         if pf_list:
            if len(pf_list) == 1:
               pf_list[0]()
            else:
               pf_list[0](pf_list[1])

   def save(self):
      """Saves the game."""

      try:
         savefile = open("dissolved.save", "wb")
      except:
         print "ERROR: Could not open dissolved.save for writing!  Cannot save."
         return

      cPickle.dump(self.global_state, savefile)
      savefile.close()
      print "===-- -  - "
      print "Game saved."
      print "==-- --   -"

   def load(self):
      """Loads the game."""

      try:
         savefile = open("dissolved.save", "rb")
      except:
         print "ERROR: Could not open dissolved.save for reading!  Cannot load."
         return

      self.global_state = cPickle.load(savefile)
      print " -  - ---==="
      print "Game loaded."
      print "  --  - --=="
