#!/usr/bin/env python
# The World Dissolved: Act 1 (Driving)
# An Interactive Novel by Phil Bordelon

import tools
import random

flavour = tools.flavour

def Act1DetermineDrivingLocations(state):
   """This function will add and remove locations from the available places
   to drive to depending on the player's actions."""

   action_list = state.global_state["allowed-action-dict"]["act1.driving"]
   if state.global_state.get("pearce-going-to-talk") and "house" not in action_list:
      action_list.append("house")
   elif state.global_state.get("act1-slept-with-pearce") and "house" in action_list:
      action_list.remove("house")
      state.global_state["pearce-going-to-talk"] = False # So it doesn't reappear.
   if state.global_state.get("know-about-boyfriend") and "coombs" not in action_list:
      action_list.append("coombs")
   elif state.global_state.get("know-about-corpse-etching") and "coombs" in action_list:
      action_list.remove("coombs")
      state.global_state["know-about-boyfriend"] = False
      if state.global_state.get("pearce-going-to-talk") and state.global_state["pearce-mood"] >= 1:
         flavour("act1.driving.pearce-call")
         state.global_state["pearce-at-home"] = True
   if state.global_state.get("know-about-corpse-etching") and "marsh" not in action_list:
      action_list.append("marsh") # No need to have a remove here, as they're not coming back.
      

def Act1DrivingMarsh(state):
   if not state.global_state.get("know-about-corpse-etching"):
      flavour("act1.driving.marsh.no")
   else:
      state.move("act1.fin.body")

def Act1DrivingOffice(state):
   if state.global_state.get("done-with-office"):
      flavour("act1.driving.office.no")
   else:
      state.move("act1.office")

def Act1DrivingPearcesHouse(state):
   if not state.global_state.get("pearce-at-home"):
      flavour("act1.driving.pearce.no")
   else:
      state.move("act1.pearce.door")

def Act1DrivingHail(state):
   if state.global_state.get("know-about-corpse-etching") and not state.global_state.get("hail-corpse-etching"):
      flavour("act1.driving.hail.etching")
      state.global_state["hail-corpse-etching"] = True
      state.global_state["hail-boyfriend"] = True
   elif state.global_state.get("know-about-boyfriend") and not state.global_state.get("hail-boyfriend"):
      flavour("act1.driving.hail.boyfriend")
      state.global_state["hail-boyfriend"] = True
   else: 
      hcount = state.global_state.get("pearce-hail-count", 0)
      if hcount < 4:
         rand_hail_flavour = random.randint(1,3)
         if rand_hail_flavour == 1:
            flavour("act1.driving.hail.random.1")
         elif rand_hail_flavour == 2:
            flavour("act1.driving.hail.random.2")
         else:
            flavour("act1.driving.hail.random.3")
      else:
         flavour("act1.driving.hail.angry")
         state.global_state["pearce-mood"] -= 1
      state.global_state["pearce-hail-count"] = hcount + 1

def init(state):
   state.location_dict["act1.driving"] = {
      "name": "act1.driving",
      "text": "act1.driving",
      "can-brief": True,
      "pre-function": [Act1DetermineDrivingLocations, state],
      "actions": [("marsh", "Return to the MARSH.", Act1DrivingMarsh, state),
                  ("office", "Head to the OFFICE.", Act1DrivingOffice, state),
                  ("coombs", "Drive to the COOMBS estate.", state.move, "act1.coombs.front-gate"),
                  ("house", "Drive over to Pearce's HOUSE.", Act1DrivingPearcesHouse, state),
                  ("hail", "Try to HAIL Pearce on the transmitter.", Act1DrivingHail, state),
                 ]
   }
   state.global_state["allowed-action-dict"]["act1.driving"] = ["office", "marsh", "hail"]
