#!/usr/bin/env python
# Dissolved Engine Tools
#

import os.path

DATA_DIR = "data"

PAGE_LENGTH = 20

def displayData (file_prefix):
   """This displays text from a file.  It breaks pages every PAGE_LENGTH
   lines.  That should probably be configurable ... somewhere."""

   filename = file_prefix + ".dat"
   try:
      file_to_read = file(os.path.join(DATA_DIR, filename), "r")
   except:
      print "ERROR: Cannot open %s for display!" % (filename)
      return

   lines_displayed = 0
   for line in file_to_read.xreadlines():
      if lines_displayed >= PAGE_LENGTH:
         raw_input("---More---")
         lines_displayed = 0
      line = line.strip()
      print line
      lines_displayed += 1
   file_to_read.close()

INVALID_KEYWORDS = ("?", "q", "s", "l", "quit", "save", "load")

def chooseAction (action_list, allowed_action_list = [], may_prompt = True):
   """Prompts the user for a choice of actions and returns the one that they
   chose.  action_list is a list of tuples; the first element is the 'keyword'
   they must type, and the second is the string to display.  Generally, you
   want to UPPERCASE the keyword so that the user has a clue as to what they
   can type.  ? is permanently reserved as "run me again" for the calling
   function (for the user to display the current situation again).  "Q" and
   "S" and "L" are also reserved for Quitting and Saving and Loading.
   
   There is also an optional allowed_action_list parameter.  If it's set,
   it's a list of keywords that are actually available to the player at the
   moment.  This is useful for locations where the available actions change
   depending on the situation.
   
   Lastly, there's an optional may_prompt parameter, which determines whether
   we bother displaying the 'You may:' prompt.  For conversations, this is
   dumb, so don't do it."""

   done = False
   keyword_list = []
   restricted = False
   if len(allowed_action_list) > 0:
      restricted = True
   for action in action_list:
      keyword = action[0].lower()
      if keyword in INVALID_KEYWORDS:
         print "ERROR: Cannot have '%s' as a keyword." % keyword
      elif keyword in keyword_list:
         print "ERROR: Cannot have duplicate keywords. (%s)" % keyword
      else:
         if (not restricted) or (action[0] in allowed_action_list):
            keyword_list.append(keyword)
   print
   while not done:
      if may_prompt:
         print "You may:"
      for action in action_list:
         if (not restricted) or (action[0] in allowed_action_list):
            print "   " + action[1]
      read_command = raw_input("--> ").strip().lower()
      if read_command == "?" or read_command == "q" or read_command == "s" or read_command == "l":
         return read_command
      elif read_command == "quit":
         return "q"
      elif read_command == "save":
         return "s"
      elif read_command == "load":
         return "l"
      elif read_command in keyword_list:
         return read_command

def hitEnter():
   """Lets the user hit enter to continue."""
   raw_input("Press Enter to continue.")

def flavour(file_prefix):
   """Helper function for flavour text; things like looking out the window,
   etc."""

   print
   displayData(file_prefix)
   print
   hitEnter()

def Idle():
   """Does nothing.  Mainly for debugging purposes."""
   print "Idling."
   hitEnter()

def PrintValue(value):
   """Prints a value.  For debugging purposes."""
   print "Value is " + repr (value)
